@@ -16,16 +16,18 @@ import sys
 from importlib import import_module
 from pathlib import Path
 
-from . import console
-from . import debug_helper
+from friendly_traceback import explain_traceback, exclude_file_from_traceback, install
+from friendly_traceback import __version__ as ft_version
+from friendly_traceback import debug_helper
+
+from friendly import console, __version__
+from friendly import set_formatter
 from .my_gettext import current_lang
 
-from . import explain_traceback, exclude_file_from_traceback, install
-from . import set_formatter, __version__
+# TODO: add friendly-traceback AND friendly version
 
-
-versions = "Friendly version {}. [Python version: {}]\n".format(
-    __version__, platform.python_version()
+versions = "\nfriendly-traceback: {}\nfriendly: {}\nPython: {}\n".format(
+    ft_version, __version__, platform.python_version()
 )
 
 
@@ -118,11 +120,9 @@ parser.add_argument(
     """,
 )
 
-
 parser.add_argument("--debug", help="""For developer use.""", action="store_true")
 parser.add_argument("--no_debug", help="""For developer use.""", action="store_true")
 
-
 parser.add_argument(
     "--include",
     help="""Specifies what content to include by default in the traceback.
@@ -131,6 +131,12 @@ parser.add_argument(
     """,
 )
 
+parser.add_argument(
+    "--python_prompt",
+    help="""Specifies that the console prompt must the regular Python prompt""",
+    action="store_true",
+)
+
 
 def main():
     _ = current_lang.translate
@@ -153,20 +159,15 @@ def main():
 
     install(lang=args.lang, include=include)
 
-    if args.background:  # pragma: no cover
-        background = args.background
-    else:
-        background = None
-
     if args.formatter:
         formatter = args.formatter  # noqa
-        if formatter in ["bw", "dark", "light", "docs", "markdown", "markdown_docs"]:
-            set_formatter(formatter, background=background)  # pragma: no cover
+        if formatter in ["repl", "dark", "light", "docs"]:
+            set_formatter(formatter, background=args.background)  # pragma: no cover
         else:
             set_formatter(import_function(args.formatter))
-            formatter = "bw"  # for the console - should not be needed
+            formatter = "dark"  # for the console - should not be needed
     else:
-        set_formatter("dark", background=background)
+        set_formatter("dark", background=args.background)
         formatter = "dark"
 
     console_defaults = {}
@@ -188,12 +189,20 @@ def main():
             explain_traceback()
         if sys.flags.interactive:  # pragma: no cover
             console.start_console(
-                local_vars=console_defaults, formatter=formatter, background=background
+                local_vars=console_defaults,
+                formatter=formatter,
+                background=args.background,
+                lang=args.lang,
+                ipython_prompt=not args.python_prompt,
             )
 
     else:  # pragma: no cover
         console.start_console(
-            local_vars=console_defaults, formatter=formatter, background=background
+            local_vars=console_defaults,
+            formatter=formatter,
+            background=args.background,
+            lang=args.lang,
+            ipython_prompt=not args.python_prompt,
         )
 
 
